AskSO - StackOverflow Python Question Assistant
-----------------------------------------------

This is a tool to help you construct a good question about Python on
`StackOverflow <http://stackoverflow.com/>`__, although it can help with
other forums too. It assumes that you've written some code that isn't
behaving correctly. This should not be a problem, as StackOverflow
generally expects you to show that you've tried something.

To install, run ``pip install ask-so`` in a terminal.

To use the tool, run ``askso`` in a terminal.
